==> box64_0.2.2%2Bdfsg.orig.tar.xz: box64-0.2.2/src/wrapped/wrappedatomic_private.h <==
#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error Meh....
#endif

//GO(__atomic_add_fetch_1, 
//GO(__atomic_add_fetch_16, 
//GO(__atomic_add_fetch_2, 
//GO(__atomic_add_fetch_4, 
//GO(__atomic_add_fetch_8, 
//GO(__atomic_and_fetch_1, 
//GO(__atomic_and_fetch_16, 
//GO(__atomic_and_fetch_2, 
//GO(__atomic_and_fetch_4, 
//GO(__atomic_and_fetch_8, 
GO(__atomic_compare_exchange, iFpii)
//GO(__atomic_compare_exchange_1, 
//GO(__atomic_compare_exchange_16, 
//GO(__atomic_compare_exchange_2, 
//GO(__atomic_compare_exchange_4, 
//GO(__atomic_compare_exchange_8, 
//GO(__atomic_exchange, 
//GO(__atomic_exchange_1, 
//GO(__atomic_exchange_16, 
//GO(__atomic_exchange_2, 
//GO(__atomic_exchange_4, 
//GO(__atomic_exchange_8, 
//GO(__atomic_feraiseexcept, 
//GO(__atomic_fetch_add_1, 
//GO(__atomic_fetch_add_16, 
//GO(__atomic_fetch_add_2, 
//GO(__atomic_fetch_add_4, 
//GO(__atomic_fetch_add_8, 
//GO(__atomic_fetch_and_1, 
//GO(__atomic_fetch_and_16, 
//GO(__atomic_fetch_and_2, 
//GO(__atomic_fetch_and_4, 
//GO(__atomic_fetch_and_8, 
//GO(__atomic_fetch_nand_1, 
//GO(__atomic_fetch_nand_16, 
//GO(__atomic_fetch_nand_2, 
//GO(__atomic_fetch_nand_4, 
//GO(__atomic_fetch_nand_8, 
//GO(__atomic_fetch_or_1, 
//GO(__atomic_fetch_or_16, 
//GO(__atomic_fetch_or_2, 
//GO(__atomic_fetch_or_4, 
//GO(__atomic_fetch_or_8, 
//GO(__atomic_fetch_sub_1, 
//GO(__atomic_fetch_sub_16, 
//GO(__atomic_fetch_sub_2, 
//GO(__atomic_fetch_sub_4, 
//GO(__atomic_fetch_sub_8, 
//GO(__atomic_fetch_xor_1, 
//GO(__atomic_fetch_xor_16, 
//GO(__atomic_fetch_xor_2, 
//GO(__atomic_fetch_xor_4, 
//GO(__atomic_fetch_xor_8, 
//GO(atomic_flag_clear, 
//GO(atomic_flag_clear_explicit, 
//GO(atomic_flag_test_and_set, 
//GO(atomic_flag_test_and_set_explicit, 
//GO(__atomic_is_lock_free, 
//GO(__atomic_load, 
//GO(__atomic_load_1, 
//GO(__atomic_load_16, 
//GO(__atomic_load_2, 
//GO(__atomic_load_4, 
//GO(__atomic_load_8, 
//GO(__atomic_nand_fetch_1, 
//GO(__atomic_nand_fetch_16, 
//GO(__atomic_nand_fetch_2, 
//GO(__atomic_nand_fetch_4, 
//GO(__atomic_nand_fetch_8, 
//GO(__atomic_or_fetch_1, 
//GO(__atomic_or_fetch_16, 
//GO(__atomic_or_fetch_2, 
//GO(__atomic_or_fetch_4, 
//GO(__atomic_or_fetch_8, 
//GO(atomic_signal_fence, 
//GO(__atomic_store, 
//GO(__atomic_store_1, 
//GO(__atomic_store_16, 
//GO(__atomic_store_2, 
//GO(__atomic_store_4, 
//GO(__atomic_store_8, 
//GO(__atomic_sub_fetch_1, 
//GO(__atomic_sub_fetch_16, 
//GO(__atomic_sub_fetch_2, 
//GO(__atomic_sub_fetch_4, 
//GO(__atomic_sub_fetch_8, 
//GO(__atomic_test_and_set_1, 
//GO(__atomic_test_and_set_16, 
//GO(__atomic_test_and_set_2, 
//GO(__atomic_test_and_set_4, 
//GO(__atomic_test_and_set_8, 
//GO(atomic_thread_fence, 
//GO(__atomic_xor_fetch_1, 
//GO(__atomic_xor_fetch_16, 
//GO(__atomic_xor_fetch_2, 
//GO(__atomic_xor_fetch_4, 
//GO(__atomic_xor_fetch_8,

==> box64_0.3.2%2Bdfsg.orig.tar.xz: box64-0.3.2/src/wrapped/wrappedatomic_private.h <==
#if !(defined(GO) && defined(GOM) && defined(GO2) && defined(DATA))
#error Meh....
#endif

//GO(__atomic_add_fetch_1, 
//GO(__atomic_add_fetch_16, 
//GO(__atomic_add_fetch_2, 
//GO(__atomic_add_fetch_4, 
//GO(__atomic_add_fetch_8, 
//GO(__atomic_and_fetch_1, 
//GO(__atomic_and_fetch_16, 
//GO(__atomic_and_fetch_2, 
//GO(__atomic_and_fetch_4, 
//GO(__atomic_and_fetch_8, 
GO(__atomic_compare_exchange, iFLpppii)
//GO(__atomic_compare_exchange_1, 
//GO(__atomic_compare_exchange_16, 
//GO(__atomic_compare_exchange_2, 
//GO(__atomic_compare_exchange_4, 
//GO(__atomic_compare_exchange_8, 
GO(__atomic_exchange, vFLpppi)
//GO(__atomic_exchange_1, 
//GO(__atomic_exchange_16, 
//GO(__atomic_exchange_2, 
//GO(__atomic_exchange_4, 
//GO(__atomic_exchange_8, 
//GO(__atomic_feraiseexcept, 
//GO(__atomic_fetch_add_1, 
//GO(__atomic_fetch_add_16, 
//GO(__atomic_fetch_add_2, 
//GO(__atomic_fetch_add_4, 
//GO(__atomic_fetch_add_8, 
//GO(__atomic_fetch_and_1, 
//GO(__atomic_fetch_and_16, 
//GO(__atomic_fetch_and_2, 
//GO(__atomic_fetch_and_4, 
//GO(__atomic_fetch_and_8, 
//GO(__atomic_fetch_nand_1, 
//GO(__atomic_fetch_nand_16, 
//GO(__atomic_fetch_nand_2, 
//GO(__atomic_fetch_nand_4, 
//GO(__atomic_fetch_nand_8, 
//GO(__atomic_fetch_or_1, 
//GO(__atomic_fetch_or_16, 
//GO(__atomic_fetch_or_2, 
//GO(__atomic_fetch_or_4, 
//GO(__atomic_fetch_or_8, 
//GO(__atomic_fetch_sub_1, 
//GO(__atomic_fetch_sub_16, 
//GO(__atomic_fetch_sub_2, 
//GO(__atomic_fetch_sub_4, 
//GO(__atomic_fetch_sub_8, 
//GO(__atomic_fetch_xor_1, 
//GO(__atomic_fetch_xor_16, 
//GO(__atomic_fetch_xor_2, 
//GO(__atomic_fetch_xor_4, 
//GO(__atomic_fetch_xor_8, 
//GO(atomic_flag_clear, 
//GO(atomic_flag_clear_explicit, 
//GO(atomic_flag_test_and_set, 
//GO(atomic_flag_test_and_set_explicit, 
GO(__atomic_is_lock_free, iFLp)
GO(__atomic_load, vFLppi)
//GO(__atomic_load_1, 
GO(__atomic_load_16, HFpi)
//GO(__atomic_load_2, 
//GO(__atomic_load_4, 
//GO(__atomic_load_8, 
//GO(__atomic_nand_fetch_1, 
//GO(__atomic_nand_fetch_16, 
//GO(__atomic_nand_fetch_2, 
//GO(__atomic_nand_fetch_4, 
//GO(__atomic_nand_fetch_8, 
//GO(__atomic_or_fetch_1, 
//GO(__atomic_or_fetch_16, 
//GO(__atomic_or_fetch_2, 
//GO(__atomic_or_fetch_4, 
//GO(__atomic_or_fetch_8, 
//GO(atomic_signal_fence, 
GO(__atomic_store, vFLppi)
//GO(__atomic_store_1, 
GO(__atomic_store_16, vFpHi)
//GO(__atomic_store_2, 
//GO(__atomic_store_4, 
//GO(__atomic_store_8, 
//GO(__atomic_sub_fetch_1, 
//GO(__atomic_sub_fetch_16, 
//GO(__atomic_sub_fetch_2, 
//GO(__atomic_sub_fetch_4, 
//GO(__atomic_sub_fetch_8, 
//GO(__atomic_test_and_set_1, 
//GO(__atomic_test_and_set_16, 
//GO(__atomic_test_and_set_2, 
//GO(__atomic_test_and_set_4, 
//GO(__atomic_test_and_set_8, 
//GO(atomic_thread_fence, 
//GO(__atomic_xor_fetch_1, 
//GO(__atomic_xor_fetch_16, 
//GO(__atomic_xor_fetch_2, 
//GO(__atomic_xor_fetch_4, 
//GO(__atomic_xor_fetch_8,
